Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(284)

Unified Diff: third_party/WebKit/public/platform/WebURLRequest.h

Issue 2484633004: Change Lo-Fi bool to bitmask to support multiple Previews types (Closed)
Patch Set: remove previews_unspecified Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/platform/WebURLRequest.h
diff --git a/third_party/WebKit/public/platform/WebURLRequest.h b/third_party/WebKit/public/platform/WebURLRequest.h
index c58a4e491222d25c0643a790d77ce7e836e6c9af..a1c51529ab2fdc01ce30e2865b38766b177d5329 100644
--- a/third_party/WebKit/public/platform/WebURLRequest.h
+++ b/third_party/WebKit/public/platform/WebURLRequest.h
@@ -136,13 +136,16 @@ class WebURLRequest {
ReportIntent, // Report metrics with UI action displayed intent.
};
- // The LoFi state which determines whether to request a Lo-Fi version of the
- // resource.
- enum LoFiState {
- LoFiUnspecified, // Let the browser process decide whether or not to
- // request the Lo-Fi version.
- LoFiOff, // Request a normal (non-Lo-Fi) version of the resource.
- LoFiOn, // Request a Lo-Fi version of the resource.
+ // The Previews state which determines whether to request a Preview version of
+ // the resource. A value of zero for Previews state means to let the browser
+ // process decide whether or not to request Preview types.
+ enum PreviewsState {
RyanSturm 2016/12/06 19:39:30 maybe nit: I can't find anything in the style guid
megjablon 2016/12/06 21:23:47 I see this done elsewhere throughout the code, so
+ ServerLoFiOn = 1 << 0, // Request a Lo-Fi version of the resource
+ // from the server.
+ ClientLoFiOn = 1 << 1, // Request a Lo-Fi version of the resource
+ // from the client.
+ PreviewsOff = 1 << 2 // Request a normal (non-Preview) version of
+ // the resource.
};
// Indicates which types of ServiceWorkers should skip handling this request.
@@ -285,10 +288,10 @@ class WebURLRequest {
BLINK_PLATFORM_EXPORT FetchRedirectMode getFetchRedirectMode() const;
BLINK_PLATFORM_EXPORT void setFetchRedirectMode(FetchRedirectMode);
- // The LoFi state which determines whether to request a Lo-Fi version of the
- // resource.
- BLINK_PLATFORM_EXPORT LoFiState getLoFiState() const;
- BLINK_PLATFORM_EXPORT void setLoFiState(LoFiState);
+ // The Previews state which determines whether to request a Preview version of
+ // the resource.
+ BLINK_PLATFORM_EXPORT int getPreviewsState() const;
+ BLINK_PLATFORM_EXPORT void setPreviewsState(int);
// Extra data associated with the underlying resource request. Resource
// requests can be copied. If non-null, each copy of a resource requests

Powered by Google App Engine
This is Rietveld 408576698